@@ -125,7 +125,7 @@ class FastDownwardExperiment(Experiment):
     #: "translator_peak_memory", "translator_time_done".
     #:
     #: Parsed attributes: "node", "planner_memory", "planner_time",
-    #: "planner_wall_clock_time".
+    #: "planner_wall_clock_time", "score_planner_memory", "score_planner_time".
     PLANNER_PARSER = os.path.join(DOWNWARD_SCRIPTS_DIR, "planner-parser.py")
 
     def __init__(self, path=None, environment=None, revision_cache=None):
@@ -176,7 +176,8 @@ class FastDownwardExperiment(Experiment):
         """Add PDDL or SAS+ benchmarks to the experiment.
 
         *benchmarks_dir* must be a path to a benchmark directory. It must
-        contain domain directories, which in turn hold PDDL or SAS+ files.
+        contain domain directories, which in turn hold PDDL or SAS+ files
+        (ending with ".pddl" or ".sas").
 
         *suite* must be a list of domain or domain:task names. ::
 
@@ -187,14 +188,14 @@ class FastDownwardExperiment(Experiment):
             >>> exp.add_suite(benchmarks_dir, ["rubiks-cube:p01.sas"])
 
         One source for benchmarks is
-        https://github.com/aibasel/downward-benchmarks. After cloning the
-        repo, you can generate suites with the ``suites.py`` script. We
-        recommend using the suite ``optimal_strips`` for optimal STRIPS planners
-        and ``satisficing`` for satisficing planners::
+        https://github.com/aibasel/downward-benchmarks. After cloning the repo,
+        you can generate suites with the ``suites.py`` script. We recommend
+        using the suite ``optimal_strips`` for optimal STRIPS planners and
+        ``satisficing`` for satisficing planners::
 
-            # Create standard optimal planning suite.
-            $ path/to/downward-benchmarks/suites.py optimal_strips
-            ['airport', ..., 'zenotravel']
+            # Create standard optimal planning suite. $
+            path/to/downward-benchmarks/suites.py optimal_strips ['airport',
+            ..., 'zenotravel']
 
         Then you can copy the generated list into your experiment script::
 
@@ -362,6 +363,7 @@ class FastDownwardExperiment(Experiment):
             )
 
     def _add_runs(self):
+        tasks = self._get_tasks()
         for algo in self._algorithms.values():
-            for task in self._get_tasks():
+            for task in tasks:
                 self.add_run(FastDownwardRun(self, algo, task))
