@@ -8,17 +8,17 @@ def find_domain_file(benchmarks_dir, domain, problem):
 
     For a given problem filename "<taskname>.<ext>", check the following
     domain filenames: "domain.pddl", "<taskname>-domain.<ext>",
-    "domain_<taskname>.<ext>" and "domain-<taskname>.<ext>", where ".<ext>"
-    is optional. Also check "<xyz>-domain.pddl" where <xyz> are the first
-    three characters of the task file name, to cover the airport domain
-    where task file names are p01-xxx.pddl and domain file names are
-    p01-domain.pddl.
+    "domain_<taskname>.<ext>" and "domain-<taskname>.<ext>", where
+    ".<ext>" is optional. Also check "<xyz>-domain.pddl" where <xyz> are
+    the first three characters of the task file name, to cover the airport
+    and psr-small domains, where problem file names are p01-xxx.pddl and
+    domain file names are p01-domain.pddl.
     """
     problem_root, ext = os.path.splitext(problem)
     domain_basenames = [
         "domain.pddl",
         problem_root + "-domain" + ext,
-        problem_root[:3] + "-domain.pddl",  # for airport
+        problem_root[:3] + "-domain.pddl",  # for airport and psr-small
         "domain_" + problem,
         "domain-" + problem,
     ]
@@ -44,7 +44,7 @@ class Domain:
             [
                 p
                 for p in os.listdir(directory)
-                if "domain" not in p and not p.endswith(".py")
+                if "domain" not in p and p.endswith((".pddl", ".sas"))
             ]
         )
         self.problems = [
