@@ -36,7 +36,7 @@ def geometric_mean(values):
     """
     assert None not in values
     exp = 1.0 / len(values)
-    return tools.product([val ** exp for val in values])
+    return tools.product([val**exp for val in values])
 
 
 def finite_sum(values):
@@ -96,7 +96,7 @@ class Attribute(str):
         value for:
 
         * *absolute*: if False, only include tasks for which all task
-          runs have values in a domain-wise table (e.g. ``coverage`` is
+          runs have values in a per-domain table (e.g. ``coverage`` is
           absolute, whereas ``expansions`` is not, because we can't
           compare algorithms A and B for task X if B has no value for
           ``expansions``).
@@ -200,6 +200,7 @@ class Report:
 
         >>> def low_init_h(run):
         ...     return run["initial_h_value"] <= 100
+        ...
         >>> report = Report(filter=low_init_h)
 
         Only include runs from "blocks" and "barman" with a timeout:
@@ -214,6 +215,7 @@ class Report:
         ...     if expansions is not None and time:
         ...         run["expansions_per_time"] = expansions / time
         ...     return run
+        ...
         >>> report = Report(
         ...     attributes=["expansions_per_time"], filter=[add_expansions_per_time]
         ... )
@@ -225,6 +227,7 @@ class Report:
         ...     paper_names = {"lama11": "LAMA 2011", "fdss_sat1": "FDSS 1"}
         ...     run["algorithm"] = paper_names[name]
         ...     return run
+        ...
 
         >>> # We want LAMA 2011 to be the leftmost column.
         >>> # filter_* filters are evaluated last, so we use the updated
@@ -371,7 +374,7 @@ class Report:
             "This happens when no significant changes occured or "
             "if for all attributes and all problems never all "
             "algorithms had a value for this attribute in a "
-            "domain-wise report."
+            "per-domain report."
         )
         return doc.render(self.output_format, {"toc": self.toc})
 
@@ -430,10 +433,14 @@ class Report:
 class CellFormatter:
     """Formating information for one cell in a table."""
 
-    def __init__(self, bold=False, count=None, link=None):
+    def __init__(
+        self, bold=False, count=None, link=None, color=None, align_right=False
+    ):
         self.bold = bold
         self.count = count
         self.link = link
+        self.color = color
+        self.align_right = align_right
 
     def format_value(self, value):
         result = str(value)
@@ -443,6 +450,14 @@ class CellFormatter:
             result = f"{result} ({self.count})"
         if self.bold:
             result = f"**{result}**"
+        if self.color:
+            result = f"{{{result}|color:{self.color}}}"
+
+        if self.align_right:
+            result = " " + result
+        else:
+            result += " "
+
         return result
 
 
@@ -471,10 +486,11 @@ class Table(collections.defaultdict):
         >>> t.add_row("prob2", {"cfg1": 15, "cfg2": 25})
         >>> def remove_quotes(s):
         ...     return s.replace('""', "")
+        ...
         >>> print(remove_quotes(str(t)))
         || expansions |  cfg1 |  cfg2 |
-         | prob1 |  10 |  20 |
-         | prob2 |  15 |  25 |
+         | prob1  |  10 |  20 |
+         | prob2  |  15 |  25 |
         >>> t.row_names
         ['prob1', 'prob2']
         >>> t.col_names
@@ -486,15 +502,15 @@ class Table(collections.defaultdict):
         >>> t.add_summary_function("SUM", sum)
         >>> print(remove_quotes(str(t)))
         || expansions |  cfg1 |  cfg2 |
-         | prob1 |  10 |  20 |
-         | prob2 |  15 |  25 |
-         | **SUM** |  25 |  45 |
+         | prob1  |  10 |  20 |
+         | prob2  |  15 |  25 |
+         | **SUM**  |  25 |  45 |
         >>> t.set_column_order(["cfg2", "cfg1"])
         >>> print(remove_quotes(str(t)))
         || expansions |  cfg2 |  cfg1 |
-         | prob1 |  20 |  10 |
-         | prob2 |  25 |  15 |
-         | **SUM** |  45 |  25 |
+         | prob1  |  20 |  10 |
+         | prob2  |  25 |  15 |
+         | **SUM**  |  45 |  25 |
         """
         collections.defaultdict.__init__(self, dict)
 
@@ -764,20 +780,13 @@ class Table(collections.defaultdict):
         default format.
         """
         formatter = self.cell_formatters.get(row_name, {}).get(col_name)
-        if formatter:
-            return formatter.format_value(value)
-
-        justify_right = isinstance(value, (float, int))
-
-        value_text = self._format_value(value)
-
-        if color is not None:
-            value_text = f"{{{value_text}|color:{color}}}"
-        if bold:
-            value_text = f"**{value_text}**"
-        if justify_right:
-            value_text = " " + value_text
-        return value_text
+        if not formatter:
+            align_right = (
+                isinstance(value, (float, int)) or value is None or value == "?"
+            )
+            value = self._format_value(value)
+            formatter = CellFormatter(bold=bold, color=color, align_right=align_right)
+        return formatter.format_value(value)
 
     def _get_markup(self, cells):
         """
